@@ -1,22 +1,22 @@
 # ./pyxb/bundles/wssplat/raw/wsoap.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:3a38467dbfe17f8bf02ac4151ad87deda2d076d0
-# Generated 2013-04-17 03:14:15.104295 by PyXB version 1.2.2
+# Generated 2013-09-18 10:35:53.276526 by PyXB version 1.2.3
 # Namespace http://www.w3.org/ns/wsdl/soap
 
 import pyxb
 import pyxb.binding
 import pyxb.binding.saxer
-import StringIO
+import io
 import pyxb.utils.utility
 import pyxb.utils.domutils
 import sys
 
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:cb04023a-a736-11e2-a432-c8600024e903')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:00c66fce-2078-11e3-ba66-c8600024e903')
 
 # Version of PyXB used to generate the bindings
-_PyXBVersion = '1.2.2'
+_PyXBVersion = '1.2.3'
 # Generated bindings are not compatible across PyXB versions
 if pyxb.__version__ != _PyXBVersion:
     raise pyxb.PyXBVersionError(_PyXBVersion)
@@ -34,8 +34,12 @@ _Namespace_wsdl.configureCategories(['typeBinding', 'elementBinding'])
 def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
     """Parse the given XML and use the document element to create a
     Python instance.
-    
-    @kw default_namespace The L{pyxb.Namespace} instance to use as the
+
+    @param xml_text An XML document.  This should be data (Python 2
+    str or Python 3 bytes), or a text (Python 2 unicode or Python 3
+    str) in the L{pyxb._InputEncoding} encoding.
+
+    @keyword default_namespace The L{pyxb.Namespace} instance to use as the
     default namespace where there is no default namespace in scope.
     If unspecified or C{None}, the namespace of the module containing
     this function will be used.
@@ -53,7 +57,10 @@ def CreateFromDocument (xml_text, default_namespace=None, location_base=None):
         default_namespace = Namespace.fallbackNamespace()
     saxer = pyxb.binding.saxer.make_parser(fallback_namespace=default_namespace, location_base=location_base)
     handler = saxer.getContentHandler()
-    saxer.parse(StringIO.StringIO(xml_text))
+    xmld = xml_text
+    if isinstance(xmld, unicode):
+        xmld = xmld.encode(pyxb._InputEncoding)
+    saxer.parse(io.BytesIO(xmld))
     instance = handler.rootObject()
     return instance
 
@@ -73,7 +80,7 @@ class TokenAny (pyxb.binding.datatypes.token, pyxb.binding.basis.enumeration_mix
     """An atomic simple type."""
 
     _ExpandedName = pyxb.namespace.ExpandedName(Namespace, u'TokenAny')
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 55, 1)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 55, 1)
     _Documentation = None
 TokenAny._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=TokenAny, enum_prefix=None)
 TokenAny.any = TokenAny._CF_enumeration.addEnumeration(unicode_value=u'#any', tag=u'any')
@@ -87,7 +94,7 @@ class STD_ANON (pyxb.binding.basis.STD_list):
     """Simple type that is a list of pyxb.binding.datatypes.QName."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 70, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 70, 2)
     _Documentation = None
 
     _ItemType = pyxb.binding.datatypes.QName
@@ -100,15 +107,15 @@ class STD_ANON_ (pyxb.binding.basis.STD_union):
     """Simple type that is a union of pyxb.binding.datatypes.QName, TokenAny."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 62, 3)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 62, 3)
     _Documentation = None
 
     _MemberTypes = ( pyxb.binding.datatypes.QName, TokenAny, )
-STD_ANON_._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_)
+STD_ANON_._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_.any = u'#any'                           # originally TokenAny.any
-STD_ANON_._InitializeFacetMap(STD_ANON_._CF_pattern,
-   STD_ANON_._CF_enumeration)
+STD_ANON_._InitializeFacetMap(STD_ANON_._CF_enumeration,
+   STD_ANON_._CF_pattern)
 
 # Union simple type: [anonymous]
 # superclasses pyxb.binding.datatypes.anySimpleType
@@ -117,15 +124,15 @@ class STD_ANON_2 (pyxb.binding.basis.STD_union):
     """Simple type that is a union of TokenAny, STD_ANON."""
 
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 68, 3)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 68, 3)
     _Documentation = None
 
     _MemberTypes = ( TokenAny, STD_ANON, )
-STD_ANON_2._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_2._CF_enumeration = pyxb.binding.facets.CF_enumeration(value_datatype=STD_ANON_2)
+STD_ANON_2._CF_pattern = pyxb.binding.facets.CF_pattern()
 STD_ANON_2.any = u'#any'                          # originally TokenAny.any
-STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_pattern,
-   STD_ANON_2._CF_enumeration)
+STD_ANON_2._InitializeFacetMap(STD_ANON_2._CF_enumeration,
+   STD_ANON_2._CF_pattern)
 
 # Complex type [anonymous] with content type ELEMENT_ONLY
 class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
@@ -134,7 +141,7 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 33, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 33, 2)
     _ElementMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType
@@ -143,16 +150,16 @@ class CTD_ANON (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     
     # Attribute ref uses Python identifier ref
     __ref = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'ref'), 'ref', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_ref', pyxb.binding.datatypes.anyURI, required=True)
-    __ref._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
-    __ref._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
+    __ref._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
+    __ref._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 36, 5)
     
     ref = property(__ref.value, __ref.set, None, None)
 
     
     # Attribute required uses Python identifier required
     __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'required'), 'required', '__httpwww_w3_orgnswsdlsoap_CTD_ANON_required', pyxb.binding.datatypes.boolean)
-    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
-    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
+    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
+    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 37, 5)
     
     required = property(__required.value, __required.set, None, None)
 
@@ -174,7 +181,7 @@ class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     _ContentTypeTag = pyxb.binding.basis.complexTypeDefinition._CT_ELEMENT_ONLY
     _Abstract = False
     _ExpandedName = None
-    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 44, 2)
+    _XSDLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 44, 2)
     _ElementMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._ElementMap.copy()
     _AttributeMap = pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType._AttributeMap.copy()
     # Base type is pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType
@@ -183,24 +190,24 @@ class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
     
     # Attribute element uses Python identifier element
     __element = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'element'), 'element', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__element', pyxb.binding.datatypes.QName, required=True)
-    __element._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
-    __element._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
+    __element._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
+    __element._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 47, 5)
     
     element = property(__element.value, __element.set, None, None)
 
     
     # Attribute mustUnderstand uses Python identifier mustUnderstand
     __mustUnderstand = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'mustUnderstand'), 'mustUnderstand', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__mustUnderstand', pyxb.binding.datatypes.boolean)
-    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
-    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
+    __mustUnderstand._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
+    __mustUnderstand._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 48, 5)
     
     mustUnderstand = property(__mustUnderstand.value, __mustUnderstand.set, None, None)
 
     
     # Attribute required uses Python identifier required
     __required = pyxb.binding.content.AttributeUse(pyxb.namespace.ExpandedName(None, u'required'), 'required', '__httpwww_w3_orgnswsdlsoap_CTD_ANON__required', pyxb.binding.datatypes.boolean)
-    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
-    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
+    __required._DeclarationLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
+    __required._UseLocation = pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 49, 5)
     
     required = property(__required.value, __required.set, None, None)
 
@@ -216,10 +223,10 @@ class CTD_ANON_ (pyxb.bundles.wssplat.wsdl20.ExtensibleDocumentedType):
 
 
 
-module = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'module'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 32, 1))
+module = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'module'), CTD_ANON, location=pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 32, 1))
 Namespace.addCategoryObject('elementBinding', module.name().localName(), module)
 
-header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsoap.xsd', 43, 1))
+header = pyxb.binding.basis.element(pyxb.namespace.ExpandedName(Namespace, u'header'), CTD_ANON_, location=pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsoap.xsd', 43, 1))
 Namespace.addCategoryObject('elementBinding', header.name().localName(), header)
 
 
@@ -231,12 +238,12 @@ def _BuildAutomaton ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(_Namespace_wsdl, u'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON._UseForTag(pyxb.namespace.ExpandedName(_Namespace_wsdl, u'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
@@ -256,12 +263,12 @@ def _BuildAutomaton_ ():
     import pyxb.utils.fac as fac
 
     counters = set()
-    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    cc_0 = fac.CounterCondition(min=0L, max=None, metadata=pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
     counters.add(cc_0)
     states = []
     final_update = set()
     final_update.add(fac.UpdateInstruction(cc_0, False))
-    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(_Namespace_wsdl, u'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.u6onFwf/PyXB-1.2.2/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
+    symbol = pyxb.binding.content.ElementUse(CTD_ANON_._UseForTag(pyxb.namespace.ExpandedName(_Namespace_wsdl, u'documentation')), pyxb.utils.utility.Location('/tmp/pyxbdist.FvaD3zy/PyXB-1.2.3/pyxb/bundles/wssplat/schemas/wsdl20.xsd', 37, 6))
     st_0 = fac.State(symbol, is_initial=True, final_update=final_update, is_unordered_catenation=False)
     states.append(st_0)
     transitions = []
